@@ -289,14 +289,18 @@ class InterceptRequest(RequestShared):
                                    r={True: "==",
                                       False: "!="}[handler_matches]))
 
-                log.extend([u'Handler:',
-                            u'{handler}'.format(handler=pformat(handler, indent=4)),
-                            u''])
-
                 if handler_matches:
                     if handler[HandlerConstant.instance].can_you_handle(uri):
                         handlers.append(handler)
 
+                log.extend([u'Handler:',
+                            u'{handler}'.format(handler=pformat(handler, indent=4)),
+                            u'Can{t} handle URI'.format(t="" if handler in handlers else "not"),
+                            u""
+                            ])
+
+
+
             return handlers
 
         except Exception as err:
